Crate sosistab3_obfsws
sosistab3_
obfsws
0.4.0
All Items
Crate Items
Re-exports
Modules
Traits
Attribute Macros
Crate
sosistab3_
obfsws
Re-exports

pub use pipe::
ObfsWsPipe
;
pub use listener::
ObfsWsListener
;
Modules

listener
pipe
ws
Traits

Pipe
Sillad overall is based on returning connection-like items that implement AsyncRead and AsyncWrite, as well as a few other things. This is called a Pipe.
Pipe
Listener
Listeners accept incoming connections, creating streams with a “remote side”. Failures are indicated by the standard I/O error type.
Attribute Macros

pin_
project
An attribute that creates projection types covering all the fields of struct or enum.